@@ -1,8 +1,11 @@
 import hmac
 import hashlib
+import json
+
 import requests
 import urllib.parse as up
 import time
+from pbinance.proxy_host import proxy_host_map
 
 
 def request_retry_wrapper(retry_num=50, retry_delay=0.1):
@@ -26,9 +29,11 @@ def request_retry_wrapper(retry_num=50, retry_delay=0.1):
 
 
 class Client():
-    def __init__(self, key='', secret=''):
+    def __init__(self, key='', secret='', proxies={}, proxy_host: str = None):
         self.key = key
         self.secret = secret
+        self.proxies = proxies
+        self.proxy_host = proxy_host
         self.session = requests.Session()
         self.session.headers.update(
             {
@@ -43,15 +48,21 @@ class Client():
         params_no_empty = {}
         for key, v in kwargs.items():
             if not (v == '' or v == None):
-                params_no_empty[key] = v
+                if type(v) == list:
+                    params_no_empty[key] = json.dumps(v).replace(" ", "")
+                else:
+                    params_no_empty[key] = v
+
         if sign:
             params_no_empty["timestamp"] = int(time.time() * 1000)
             query_string = up.urlencode(params_no_empty, True).replace("%40", "@")
             signature = self._get_sign(query_string)
             params_no_empty["signature"] = signature
-        url = up.urljoin(api_url, path)
-
-
+        if not self.proxy_host:
+            url = up.urljoin(api_url, path)
+        else:
+            proxy_api_url = proxy_host_map[api_url].format(host=self.proxy_host)
+            url = proxy_api_url + path
         response = getattr(self.session, method.lower())(
             url=url,
             params=up.urlencode(params_no_empty, True).replace("%40", "@")
