@@ -5,35 +5,35 @@ from typing import Union
 
 # 账户与交易
 class _CMAccountTradeEndpoints():
-    set_positionSide_dual = ['https://dapi.binance.com/','POST', '/dapi/v1/positionSide/dual', True]  # 更改持仓模式(TRADE)
-    get_positionSide_dual = ['https://dapi.binance.com/','GET', '/dapi/v1/positionSide/dual', True]  # 查询持仓模式(USER_DATA)
-    set_order = ['https://dapi.binance.com/','POST', '/dapi/v1/order', True]  # 下单 (TRADE)
-    set_order_test = ['https://dapi.binance.com/','POST', '/dapi/v1/order/test', True]  # 测试下单接口 (TRADE)
-    alter_order = ['https://dapi.binance.com/','PUT', '/dapi/v1/order', True]  # 修改订单 (TRADE)
-    set_batchOrders = ['https://dapi.binance.com/','POST', '/dapi/v1/batchOrders', True]  # 批量下单 (TRADE)
-    alter_batchOrders = ['https://dapi.binance.com/','PUT', '/dapi/v1/batchOrders', True]  # 批量修改订单 (TRADE)
-    get_orderAmendment = ['https://dapi.binance.com/','GET', '/dapi/v1/orderAmendment', True]  # 查询订单修改历史 (USER_DATA)
-    get_order = ['https://dapi.binance.com/','GET', '/dapi/v1/order', True]  # 查询订单 (USER_DATA)
-    cancel_order = ['https://dapi.binance.com/','DELETE', '/dapi/v1/order', True]  # 撤销订单 (TRADE)
-    cancel_allOpenOrders = ['https://dapi.binance.com/','DELETE', '/dapi/v1/allOpenOrders', True]  # 撤销全部订单 (TRADE)
-    cancel_batchOrders = ['https://dapi.binance.com/','DELETE', '/dapi/v1/batchOrders', True]  # 批量撤销订单 (TRADE)
-    set_countdownCancelAll = ['https://dapi.binance.com/','POST', '/dapi/v1/countdownCancelAll', True]  # 倒计时撤销所有订单 (TRADE)
-    get_openOrder = ['https://dapi.binance.com/','GET', '/dapi/v1/openOrder', True]  # 查询当前挂单 (USER_DATA)
-    get_openOrders = ['https://dapi.binance.com/','GET', '/dapi/v1/openOrders', True]  # 查看当前全部挂单 (USER_DATA)
-    get_allOrders = ['https://dapi.binance.com/','GET', '/dapi/v1/allOrders', True]  # 查询所有订单(包括历史订单) (USER_DATA)
-    get_balance = ['https://dapi.binance.com/','GET', '/dapi/v1/balance', True]  # 账户余额 (USER_DATA)
-    get_account = ['https://dapi.binance.com/','GET', '/dapi/v1/account', True]  # 账户信息 (USER_DATA)
-    set_leverage = ['https://dapi.binance.com/','POST', '/dapi/v1/leverage', True]  # 调整开仓杠杆 (TRADE)
-    set_marginType = ['https://dapi.binance.com/','POST', '/dapi/v1/marginType', True]  # 变换逐全仓模式 (TRADE)
-    set_positionMargin = ['https://dapi.binance.com/','POST', '/dapi/v1/positionMargin', True]  # 调整逐仓保证金 (TRADE)
-    get_positionMargin_history = ['https://dapi.binance.com/','GET', '/dapi/v1/positionMargin/history', True]  # 逐仓保证金变动历史 (TRADE)
-    get_positionRisk = ['https://dapi.binance.com/','GET', '/dapi/v1/positionRisk', True]  # 用户持仓风险
-    get_userTrades = ['https://dapi.binance.com/','GET', '/dapi/v1/userTrades', True]  # 账户成交历史 (USER_DATA)
-    get_income = ['https://dapi.binance.com/','GET', '/dapi/v1/income', True]  # 获取账户损益资金流水(USER_DATA)
-    get_leverageBracket = ['https://dapi.binance.com/','GET', '/dapi/v2/leverageBracket', False]  # 交易对杠杆分层标准 (USER_DATA)
-    get_forceOrders = ['https://dapi.binance.com/','GET', '/dapi/v1/forceOrders', False]  # 用户强平单历史 (USER_DATA)
-    get_adlQuantile = ['https://dapi.binance.com/','GET', '/dapi/v1/adlQuantile', False]  # 持仓ADL队列估算 (USER_DATA)
-    get_commissionRate = ['https://dapi.binance.com/','GET', '/dapi/v1/commissionRate', True]  # 用户手续费率 (USER_DATA)
+    set_positionSide_dual = ['https://dapi.binance.com','POST', '/dapi/v1/positionSide/dual', True]  # 更改持仓模式(TRADE)
+    get_positionSide_dual = ['https://dapi.binance.com','GET', '/dapi/v1/positionSide/dual', True]  # 查询持仓模式(USER_DATA)
+    set_order = ['https://dapi.binance.com','POST', '/dapi/v1/order', True]  # 下单 (TRADE)
+    set_order_test = ['https://dapi.binance.com','POST', '/dapi/v1/order/test', True]  # 测试下单接口 (TRADE)
+    alter_order = ['https://dapi.binance.com','PUT', '/dapi/v1/order', True]  # 修改订单 (TRADE)
+    set_batchOrders = ['https://dapi.binance.com','POST', '/dapi/v1/batchOrders', True]  # 批量下单 (TRADE)
+    alter_batchOrders = ['https://dapi.binance.com','PUT', '/dapi/v1/batchOrders', True]  # 批量修改订单 (TRADE)
+    get_orderAmendment = ['https://dapi.binance.com','GET', '/dapi/v1/orderAmendment', True]  # 查询订单修改历史 (USER_DATA)
+    get_order = ['https://dapi.binance.com','GET', '/dapi/v1/order', True]  # 查询订单 (USER_DATA)
+    cancel_order = ['https://dapi.binance.com','DELETE', '/dapi/v1/order', True]  # 撤销订单 (TRADE)
+    cancel_allOpenOrders = ['https://dapi.binance.com','DELETE', '/dapi/v1/allOpenOrders', True]  # 撤销全部订单 (TRADE)
+    cancel_batchOrders = ['https://dapi.binance.com','DELETE', '/dapi/v1/batchOrders', True]  # 批量撤销订单 (TRADE)
+    set_countdownCancelAll = ['https://dapi.binance.com','POST', '/dapi/v1/countdownCancelAll', True]  # 倒计时撤销所有订单 (TRADE)
+    get_openOrder = ['https://dapi.binance.com','GET', '/dapi/v1/openOrder', True]  # 查询当前挂单 (USER_DATA)
+    get_openOrders = ['https://dapi.binance.com','GET', '/dapi/v1/openOrders', True]  # 查看当前全部挂单 (USER_DATA)
+    get_allOrders = ['https://dapi.binance.com','GET', '/dapi/v1/allOrders', True]  # 查询所有订单(包括历史订单) (USER_DATA)
+    get_balance = ['https://dapi.binance.com','GET', '/dapi/v1/balance', True]  # 账户余额 (USER_DATA)
+    get_account = ['https://dapi.binance.com','GET', '/dapi/v1/account', True]  # 账户信息 (USER_DATA)
+    set_leverage = ['https://dapi.binance.com','POST', '/dapi/v1/leverage', True]  # 调整开仓杠杆 (TRADE)
+    set_marginType = ['https://dapi.binance.com','POST', '/dapi/v1/marginType', True]  # 变换逐全仓模式 (TRADE)
+    set_positionMargin = ['https://dapi.binance.com','POST', '/dapi/v1/positionMargin', True]  # 调整逐仓保证金 (TRADE)
+    get_positionMargin_history = ['https://dapi.binance.com','GET', '/dapi/v1/positionMargin/history', True]  # 逐仓保证金变动历史 (TRADE)
+    get_positionRisk = ['https://dapi.binance.com','GET', '/dapi/v1/positionRisk', True]  # 用户持仓风险
+    get_userTrades = ['https://dapi.binance.com','GET', '/dapi/v1/userTrades', True]  # 账户成交历史 (USER_DATA)
+    get_income = ['https://dapi.binance.com','GET', '/dapi/v1/income', True]  # 获取账户损益资金流水(USER_DATA)
+    get_leverageBracket = ['https://dapi.binance.com','GET', '/dapi/v2/leverageBracket', False]  # 交易对杠杆分层标准 (USER_DATA)
+    get_forceOrders = ['https://dapi.binance.com','GET', '/dapi/v1/forceOrders', False]  # 用户强平单历史 (USER_DATA)
+    get_adlQuantile = ['https://dapi.binance.com','GET', '/dapi/v1/adlQuantile', False]  # 持仓ADL队列估算 (USER_DATA)
+    get_commissionRate = ['https://dapi.binance.com','GET', '/dapi/v1/commissionRate', True]  # 用户手续费率 (USER_DATA)
 
 
 class CMAccountTrade(Client):
