@@ -4,51 +4,51 @@ from typing import Union
 
 
 class _MarginAccountTradeEndpoints():
-    set_transfer = ['https://api.binance.com/', 'POST', '/sapi/v1/margin/transfer', True]  # 全仓杠杆账户划转 (MARGIN)
-    set_loan = ['https://api.binance.com/', 'POST', '/sapi/v1/margin/loan', True]  # 杠杆账户借贷 (MARGIN)
-    set_repay = ['https://api.binance.com/', 'POST', '/sapi/v1/margin/repay', True]  # 杠杆账户归还借贷 (MARGIN)
-    get_asset = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/asset', False]  # 查询杠杆资产 (MARKET_DATA)
-    get_pair = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/pair', False]  # 查询全仓杠杆交易对 (MARKET_DATA)
-    get_allAssets = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/allAssets', False]  # 获取所有杠杆资产信息 (MARKET_DATA)
-    get_allPairs = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/allPairs', False]  # 获取所有全仓杠杆交易对(MARKET_DATA)
-    get_priceIndex = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/priceIndex', False]  # 查询杠杆价格指数 (MARKET_DATA)
-    set_order = ['https://api.binance.com/', 'POST', '/sapi/v1/margin/order', True]  # 杠杆账户下单 (TRADE)
-    cancel_order = ['https://api.binance.com/', 'DELETE', '/sapi/v1/margin/order', True]  # 杠杆账户撤销订单 (TRADE)
-    cancel_openOrders = ['https://api.binance.com/', 'DELETE', '/sapi/v1/margin/openOrders', True]  # 杠杆账户撤销单一交易对的所有挂单 (TRADE)
-    get_transfer = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/transfer', True]  # 获取全仓杠杆划转历史 (USER_DATA)
-    get_loan = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/loan', True]  # 查询借贷记录 (USER_DATA)
-    get_repay = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/repay', True]  # 查询还贷记录 (USER_DATA)
-    get_interestHistory = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/interestHistory', True]  # 获取利息历史 (USER_DATA)
-    get_cross_account = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/account', True]  # 查询全仓杠杆账户详情 (USER_DATA)
-    get_forceLiquidationRec = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/forceLiquidationRec', True]  # 获取账户强制平仓记录(USER_DATA)
-    get_order = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/order', True]  # 查询杠杆账户订单 (USER_DATA)
-    get_openOrders = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/openOrders', True]  # 查询杠杆账户挂单记录 (USER_DATA)
-    get_allOrders = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/allOrders', True]  # 查询杠杆账户的所有订单 (USER_DATA)
-    set_order_oco = ['https://api.binance.com/', 'POST', '/sapi/v1/margin/order/oco', True]  # 杠杆账户 OCO 下单(TRADE)
-    cancel_orderList = ['https://api.binance.com/', 'DELETE', '/sapi/v1/margin/orderList', True]  # 取消杠杆账户 OCO 订单(TRADE)
-    get_orderList = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/orderList', True]  # 查询杠杆账户 OCO (USER_DATA)
-    get_allOrderList = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/allOrderList', True]  # 查询特定杠杆账户所有 OCO (USER_DATA)
-    get_openOrderList = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/openOrderList', True]  # 查询杠杆账户 OCO 挂单 (USER_DATA)
-    get_myTrades = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/myTrades', True]  # 查询杠杆账户交易历史 (USER_DATA)
-    get_maxBorrowable = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/maxBorrowable', True]  # 查询账户最大可借贷额度(USER_DATA)
-    get_maxTransferable = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/maxTransferable', True]  # 查询最大可转出额 (USER_DATA)
-    get_tradeCoeff = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/tradeCoeff', True]  # 查询Margin账户信息汇总 (USER_DATA)
-    set_isolated_transfer = ['https://api.binance.com/', 'POST', '/sapi/v1/margin/isolated/transfer', True]  # 杠杆逐仓账户划转 (MARGIN)
-    get_isolated_transfer = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/isolated/transfer', True]  # 获取杠杆逐仓划转历史 (USER_DATA)
-    get_isolated_account = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/isolated/account', True]  # 查询杠杆逐仓账户信息 (USER_DATA)
-    delete_isolated_account = ['https://api.binance.com/', 'DELETE', '/sapi/v1/margin/isolated/account', True]  # 杠杆逐仓账户停用 (TRADE)
-    set_isolated_account = ['https://api.binance.com/', 'POST', '/sapi/v1/margin/isolated/account', True]  # 杠杆逐仓账户启用 (TRADE)
-    get_isolated_accountLimit = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/isolated/accountLimit', True]  # 查询杠杆逐仓账户启用限制 (USER_DATA)
-    get_isolated_pair = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/isolated/pair', True]  # 查询逐仓杠杆交易对 (USER_DATA)
-    get_isolated_allPairs = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/isolated/allPairs', True]  # 获取所有逐仓杠杆交易对(USER_DATA)
-    set_bnbBurn = ['https://api.binance.com/', 'POST', '/sapi/v1/bnbBurn', True]  # 现货交易和杠杆利息BNB抵扣开关(USER_DATA)
-    get_bnbBurn = ['https://api.binance.com/', 'GET', '/sapi/v1/bnbBurn', True]  # 获取BNB抵扣开关状态 (USER_DATA)
-    get_interestRateHistory = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/interestRateHistory', True]  # 获取杠杆利率历史 (USER_DATA)
-    get_crossMarginData = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/crossMarginData', True]  # 获取全仓杠杆利率及限额 (USER_DATA)
-    get_isolatedMarginData = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/isolatedMarginData', True]  # 获取逐仓杠杆利率及限额 (USER_DATA)
-    get_isolatedMarginTier = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/isolatedMarginTier', True]  # 获取逐仓档位信息 (USER_DATA)
-    get_rateLimit_order = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/rateLimit/order', False]  # 查询目前杠杆账户下单数 (TRADE)
-    get_dribblet = ['https://api.binance.com/', 'GET', '/sapi/v1/margin/dribblet', True]  # 杠杆小额资产转换BNB历史 (USER_DATA
+    set_transfer = ['https://api.binance.com', 'POST', '/sapi/v1/margin/transfer', True]  # 全仓杠杆账户划转 (MARGIN)
+    set_loan = ['https://api.binance.com', 'POST', '/sapi/v1/margin/loan', True]  # 杠杆账户借贷 (MARGIN)
+    set_repay = ['https://api.binance.com', 'POST', '/sapi/v1/margin/repay', True]  # 杠杆账户归还借贷 (MARGIN)
+    get_asset = ['https://api.binance.com', 'GET', '/sapi/v1/margin/asset', False]  # 查询杠杆资产 (MARKET_DATA)
+    get_pair = ['https://api.binance.com', 'GET', '/sapi/v1/margin/pair', False]  # 查询全仓杠杆交易对 (MARKET_DATA)
+    get_allAssets = ['https://api.binance.com', 'GET', '/sapi/v1/margin/allAssets', False]  # 获取所有杠杆资产信息 (MARKET_DATA)
+    get_allPairs = ['https://api.binance.com', 'GET', '/sapi/v1/margin/allPairs', False]  # 获取所有全仓杠杆交易对(MARKET_DATA)
+    get_priceIndex = ['https://api.binance.com', 'GET', '/sapi/v1/margin/priceIndex', False]  # 查询杠杆价格指数 (MARKET_DATA)
+    set_order = ['https://api.binance.com', 'POST', '/sapi/v1/margin/order', True]  # 杠杆账户下单 (TRADE)
+    cancel_order = ['https://api.binance.com', 'DELETE', '/sapi/v1/margin/order', True]  # 杠杆账户撤销订单 (TRADE)
+    cancel_openOrders = ['https://api.binance.com', 'DELETE', '/sapi/v1/margin/openOrders', True]  # 杠杆账户撤销单一交易对的所有挂单 (TRADE)
+    get_transfer = ['https://api.binance.com', 'GET', '/sapi/v1/margin/transfer', True]  # 获取全仓杠杆划转历史 (USER_DATA)
+    get_loan = ['https://api.binance.com', 'GET', '/sapi/v1/margin/loan', True]  # 查询借贷记录 (USER_DATA)
+    get_repay = ['https://api.binance.com', 'GET', '/sapi/v1/margin/repay', True]  # 查询还贷记录 (USER_DATA)
+    get_interestHistory = ['https://api.binance.com', 'GET', '/sapi/v1/margin/interestHistory', True]  # 获取利息历史 (USER_DATA)
+    get_cross_account = ['https://api.binance.com', 'GET', '/sapi/v1/margin/account', True]  # 查询全仓杠杆账户详情 (USER_DATA)
+    get_forceLiquidationRec = ['https://api.binance.com', 'GET', '/sapi/v1/margin/forceLiquidationRec', True]  # 获取账户强制平仓记录(USER_DATA)
+    get_order = ['https://api.binance.com', 'GET', '/sapi/v1/margin/order', True]  # 查询杠杆账户订单 (USER_DATA)
+    get_openOrders = ['https://api.binance.com', 'GET', '/sapi/v1/margin/openOrders', True]  # 查询杠杆账户挂单记录 (USER_DATA)
+    get_allOrders = ['https://api.binance.com', 'GET', '/sapi/v1/margin/allOrders', True]  # 查询杠杆账户的所有订单 (USER_DATA)
+    set_order_oco = ['https://api.binance.com', 'POST', '/sapi/v1/margin/order/oco', True]  # 杠杆账户 OCO 下单(TRADE)
+    cancel_orderList = ['https://api.binance.com', 'DELETE', '/sapi/v1/margin/orderList', True]  # 取消杠杆账户 OCO 订单(TRADE)
+    get_orderList = ['https://api.binance.com', 'GET', '/sapi/v1/margin/orderList', True]  # 查询杠杆账户 OCO (USER_DATA)
+    get_allOrderList = ['https://api.binance.com', 'GET', '/sapi/v1/margin/allOrderList', True]  # 查询特定杠杆账户所有 OCO (USER_DATA)
+    get_openOrderList = ['https://api.binance.com', 'GET', '/sapi/v1/margin/openOrderList', True]  # 查询杠杆账户 OCO 挂单 (USER_DATA)
+    get_myTrades = ['https://api.binance.com', 'GET', '/sapi/v1/margin/myTrades', True]  # 查询杠杆账户交易历史 (USER_DATA)
+    get_maxBorrowable = ['https://api.binance.com', 'GET', '/sapi/v1/margin/maxBorrowable', True]  # 查询账户最大可借贷额度(USER_DATA)
+    get_maxTransferable = ['https://api.binance.com', 'GET', '/sapi/v1/margin/maxTransferable', True]  # 查询最大可转出额 (USER_DATA)
+    get_tradeCoeff = ['https://api.binance.com', 'GET', '/sapi/v1/margin/tradeCoeff', True]  # 查询Margin账户信息汇总 (USER_DATA)
+    set_isolated_transfer = ['https://api.binance.com', 'POST', '/sapi/v1/margin/isolated/transfer', True]  # 杠杆逐仓账户划转 (MARGIN)
+    get_isolated_transfer = ['https://api.binance.com', 'GET', '/sapi/v1/margin/isolated/transfer', True]  # 获取杠杆逐仓划转历史 (USER_DATA)
+    get_isolated_account = ['https://api.binance.com', 'GET', '/sapi/v1/margin/isolated/account', True]  # 查询杠杆逐仓账户信息 (USER_DATA)
+    delete_isolated_account = ['https://api.binance.com', 'DELETE', '/sapi/v1/margin/isolated/account', True]  # 杠杆逐仓账户停用 (TRADE)
+    set_isolated_account = ['https://api.binance.com', 'POST', '/sapi/v1/margin/isolated/account', True]  # 杠杆逐仓账户启用 (TRADE)
+    get_isolated_accountLimit = ['https://api.binance.com', 'GET', '/sapi/v1/margin/isolated/accountLimit', True]  # 查询杠杆逐仓账户启用限制 (USER_DATA)
+    get_isolated_pair = ['https://api.binance.com', 'GET', '/sapi/v1/margin/isolated/pair', True]  # 查询逐仓杠杆交易对 (USER_DATA)
+    get_isolated_allPairs = ['https://api.binance.com', 'GET', '/sapi/v1/margin/isolated/allPairs', True]  # 获取所有逐仓杠杆交易对(USER_DATA)
+    set_bnbBurn = ['https://api.binance.com', 'POST', '/sapi/v1/bnbBurn', True]  # 现货交易和杠杆利息BNB抵扣开关(USER_DATA)
+    get_bnbBurn = ['https://api.binance.com', 'GET', '/sapi/v1/bnbBurn', True]  # 获取BNB抵扣开关状态 (USER_DATA)
+    get_interestRateHistory = ['https://api.binance.com', 'GET', '/sapi/v1/margin/interestRateHistory', True]  # 获取杠杆利率历史 (USER_DATA)
+    get_crossMarginData = ['https://api.binance.com', 'GET', '/sapi/v1/margin/crossMarginData', True]  # 获取全仓杠杆利率及限额 (USER_DATA)
+    get_isolatedMarginData = ['https://api.binance.com', 'GET', '/sapi/v1/margin/isolatedMarginData', True]  # 获取逐仓杠杆利率及限额 (USER_DATA)
+    get_isolatedMarginTier = ['https://api.binance.com', 'GET', '/sapi/v1/margin/isolatedMarginTier', True]  # 获取逐仓档位信息 (USER_DATA)
+    get_rateLimit_order = ['https://api.binance.com', 'GET', '/sapi/v1/margin/rateLimit/order', False]  # 查询目前杠杆账户下单数 (TRADE)
+    get_dribblet = ['https://api.binance.com', 'GET', '/sapi/v1/margin/dribblet', True]  # 杠杆小额资产转换BNB历史 (USER_DATA
 
 
 class MarginAccountTrade(Client):
