@@ -5,41 +5,41 @@ from typing import Union
 
 # 子母账户
 class _SubAccountEndpoints():
-    set_virtualSubAccount = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/virtualSubAccount', True]  # 创建虚拟子账户（适用主账户）
-    get_list = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/list', True]  # 查询子账户列表（适用主账户）
-    get_transfer_history = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/sub/transfer/history', True]  # 查询子账户现货资金划转历史 (适用主账户)
-    get_futures_internalTransfer = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/futures/internalTransfer', True]  # 查询子账户合约资金划转历史 (适用主账户)
-    set_futures_internalTransfer = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/futures/internalTransfer', True]  # 执行子账户合约资金划转 (适用主账户)
-    get_assets = ['https://api.binance.com/','GET', '/sapi/v3/sub-account/assets', True]  # 查询子账户资产 (适用主账户)
-    get_spotSummary = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/spotSummary', True]  # 查询子账户现货资产汇总 (适用主账户)
-    get_capital_deposit_subAddress = ['https://api.binance.com/','GET', '/sapi/v1/capital/deposit/subAddress', True]  # 获取子账户充值地址 (适用主账户)
-    get_capital_deposit_subHisrec = ['https://api.binance.com/','GET', '/sapi/v1/capital/deposit/subHisrec', True]  # 获取子账户充值记录 (适用主账户)
-    get_status = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/status', True]  # 查询子账户Margin/Futures状态 (适用主账户)
-    set_margin_enable = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/margin/enable', True]  # 为子账户开通Margin (适用主账户)
-    get_margin_account = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/margin/account', True]  # 查询子账户Margin账户详情 (适用主账户)
-    get_margin_accountSummary = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/margin/accountSummary', True]  # 查询子账户Margin账户汇总 (适用主账户)
-    set_futures_enable = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/futures/enable', True]  # 为子账户开通Futures (适用主账户)
-    set_futures_transfer = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/futures/transfer', True]  # 子账户Futures划转 (仅适用主账户)
-    set_margin_transfer = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/margin/transfer', True]  # 子账户Margin划转 (仅适用主账户)
-    set_transfer_subToSub = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/transfer/subToSub', True]  # 向共同主账户下的子账户主动划转 (仅适用子账户)
-    set_transfer_subToMaster = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/transfer/subToMaster', True]  # 向主账户主动划转 (仅适用子账户)
-    get_transfer_subUserHistory = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/transfer/subUserHistory', True]  # 查询子账户划转历史 (仅适用子账户)
-    set_universalTransfer = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/universalTransfer', True]  # 子母账户万能划转 (适用主账户)
-    get_universalTransfer = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/universalTransfer', True]  # 查询子母账户万能划转历史 (适用主账户)
-    get_futures_account = ['https://api.binance.com/','GET', '/sapi/v2/sub-account/futures/account', True]  # 查询子账户Futures账户详情V2 (适用主账户)
-    get_futures_accountSummary = ['https://api.binance.com/','GET', '/sapi/v2/sub-account/futures/accountSummary', True]  # 查询子账户Futures账户汇总V2 (适用主账户)
-    get_futures_positionRisk = ['https://api.binance.com/','GET', '/sapi/v2/sub-account/futures/positionRisk', True]  # 查询子账户合约持仓信息V2 (仅适用主账户)
-    set_blvt_enable = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/blvt/enable', True]  # 为子账户开通杠杆代币 (适用母账户)
+    set_virtualSubAccount = ['https://api.binance.com','POST', '/sapi/v1/sub-account/virtualSubAccount', True]  # 创建虚拟子账户（适用主账户）
+    get_list = ['https://api.binance.com','GET', '/sapi/v1/sub-account/list', True]  # 查询子账户列表（适用主账户）
+    get_transfer_history = ['https://api.binance.com','GET', '/sapi/v1/sub-account/sub/transfer/history', True]  # 查询子账户现货资金划转历史 (适用主账户)
+    get_futures_internalTransfer = ['https://api.binance.com','GET', '/sapi/v1/sub-account/futures/internalTransfer', True]  # 查询子账户合约资金划转历史 (适用主账户)
+    set_futures_internalTransfer = ['https://api.binance.com','POST', '/sapi/v1/sub-account/futures/internalTransfer', True]  # 执行子账户合约资金划转 (适用主账户)
+    get_assets = ['https://api.binance.com','GET', '/sapi/v3/sub-account/assets', True]  # 查询子账户资产 (适用主账户)
+    get_spotSummary = ['https://api.binance.com','GET', '/sapi/v1/sub-account/spotSummary', True]  # 查询子账户现货资产汇总 (适用主账户)
+    get_capital_deposit_subAddress = ['https://api.binance.com','GET', '/sapi/v1/capital/deposit/subAddress', True]  # 获取子账户充值地址 (适用主账户)
+    get_capital_deposit_subHisrec = ['https://api.binance.com','GET', '/sapi/v1/capital/deposit/subHisrec', True]  # 获取子账户充值记录 (适用主账户)
+    get_status = ['https://api.binance.com','GET', '/sapi/v1/sub-account/status', True]  # 查询子账户Margin/Futures状态 (适用主账户)
+    set_margin_enable = ['https://api.binance.com','POST', '/sapi/v1/sub-account/margin/enable', True]  # 为子账户开通Margin (适用主账户)
+    get_margin_account = ['https://api.binance.com','GET', '/sapi/v1/sub-account/margin/account', True]  # 查询子账户Margin账户详情 (适用主账户)
+    get_margin_accountSummary = ['https://api.binance.com','GET', '/sapi/v1/sub-account/margin/accountSummary', True]  # 查询子账户Margin账户汇总 (适用主账户)
+    set_futures_enable = ['https://api.binance.com','POST', '/sapi/v1/sub-account/futures/enable', True]  # 为子账户开通Futures (适用主账户)
+    set_futures_transfer = ['https://api.binance.com','POST', '/sapi/v1/sub-account/futures/transfer', True]  # 子账户Futures划转 (仅适用主账户)
+    set_margin_transfer = ['https://api.binance.com','POST', '/sapi/v1/sub-account/margin/transfer', True]  # 子账户Margin划转 (仅适用主账户)
+    set_transfer_subToSub = ['https://api.binance.com','POST', '/sapi/v1/sub-account/transfer/subToSub', True]  # 向共同主账户下的子账户主动划转 (仅适用子账户)
+    set_transfer_subToMaster = ['https://api.binance.com','POST', '/sapi/v1/sub-account/transfer/subToMaster', True]  # 向主账户主动划转 (仅适用子账户)
+    get_transfer_subUserHistory = ['https://api.binance.com','GET', '/sapi/v1/sub-account/transfer/subUserHistory', True]  # 查询子账户划转历史 (仅适用子账户)
+    set_universalTransfer = ['https://api.binance.com','POST', '/sapi/v1/sub-account/universalTransfer', True]  # 子母账户万能划转 (适用主账户)
+    get_universalTransfer = ['https://api.binance.com','GET', '/sapi/v1/sub-account/universalTransfer', True]  # 查询子母账户万能划转历史 (适用主账户)
+    get_futures_account = ['https://api.binance.com','GET', '/sapi/v2/sub-account/futures/account', True]  # 查询子账户Futures账户详情V2 (适用主账户)
+    get_futures_accountSummary = ['https://api.binance.com','GET', '/sapi/v2/sub-account/futures/accountSummary', True]  # 查询子账户Futures账户汇总V2 (适用主账户)
+    get_futures_positionRisk = ['https://api.binance.com','GET', '/sapi/v2/sub-account/futures/positionRisk', True]  # 查询子账户合约持仓信息V2 (仅适用主账户)
+    set_blvt_enable = ['https://api.binance.com','POST', '/sapi/v1/sub-account/blvt/enable', True]  # 为子账户开通杠杆代币 (适用母账户)
     sert_subAccountApi_ipRestriction = ['','POST','/sapi/v1/sub-account/subAccountApi/ipRestriction',True]  #为子账户API Key开启/关闭IP白名单 (适用母账户)
-    set_subAccountApi_ipRestriction_ipList = ['https://api.binance.com/','POST', '/sapi/v1/sub-account/subAccountApi/ipRestriction/ipList', True]  # 为子账户API Key添加IP白名单 (适用母账户)
-    get_subAccountApi_ipRestriction = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/subAccountApi/ipRestriction', True]  # 查询子账户API Key IP白名单 (适用母账户)
-    delete_subAccountApi_ipRestriction_ipList = ['https://api.binance.com/','DELETE', '/sapi/v1/sub-account/subAccountApi/ipRestriction/ipList', True]  # 删除子账户API Key IP白名单 (适用母账户)
-    get_apiRestrictions_ipRestriction_thirdPartyList = ['https://api.binance.com/','GET', '/sapi/v1/sub-account/apiRestrictions/ipRestriction/thirdPartyList', False]  # 取得子帳戶API key IP三方名單 (适用母账户)
-    set_subAccountApi_ipRestriction = ['https://api.binance.com/','POST', '/sapi/v2/sub-account/subAccountApi/ipRestriction', True]  # 为子账户API Key更新IP白名单 (适用母账户)
-    set_managed_subaccount_deposit = ['https://api.binance.com/','POST', '/sapi/v1/managed-subaccount/deposit', True]  # 投资人账户为托管子账户充值资产 (适用投资人母账户)
-    get_managed_subaccount_asset = ['https://api.binance.com/','GET', '/sapi/v1/managed-subaccount/asset', True]  # 投资人账户查询托管子账户资产 (适用投资人母账户)
-    set_managed_subaccount_withdraw = ['https://api.binance.com/','POST', '/sapi/v1/managed-subaccount/withdraw', True]  # 投资人账户为托管子账户提币资产 (适用投资人母账户)
-    get_managed_subaccount_accountSnapshot = ['https://api.binance.com/','GET', '/sapi/v1/managed-subaccount/accountSnapshot', True]  # 查询托管子账户资产快照 (适用投资人母账户)
+    set_subAccountApi_ipRestriction_ipList = ['https://api.binance.com','POST', '/sapi/v1/sub-account/subAccountApi/ipRestriction/ipList', True]  # 为子账户API Key添加IP白名单 (适用母账户)
+    get_subAccountApi_ipRestriction = ['https://api.binance.com','GET', '/sapi/v1/sub-account/subAccountApi/ipRestriction', True]  # 查询子账户API Key IP白名单 (适用母账户)
+    delete_subAccountApi_ipRestriction_ipList = ['https://api.binance.com','DELETE', '/sapi/v1/sub-account/subAccountApi/ipRestriction/ipList', True]  # 删除子账户API Key IP白名单 (适用母账户)
+    get_apiRestrictions_ipRestriction_thirdPartyList = ['https://api.binance.com','GET', '/sapi/v1/sub-account/apiRestrictions/ipRestriction/thirdPartyList', False]  # 取得子帳戶API key IP三方名單 (适用母账户)
+    set_subAccountApi_ipRestriction = ['https://api.binance.com','POST', '/sapi/v2/sub-account/subAccountApi/ipRestriction', True]  # 为子账户API Key更新IP白名单 (适用母账户)
+    set_managed_subaccount_deposit = ['https://api.binance.com','POST', '/sapi/v1/managed-subaccount/deposit', True]  # 投资人账户为托管子账户充值资产 (适用投资人母账户)
+    get_managed_subaccount_asset = ['https://api.binance.com','GET', '/sapi/v1/managed-subaccount/asset', True]  # 投资人账户查询托管子账户资产 (适用投资人母账户)
+    set_managed_subaccount_withdraw = ['https://api.binance.com','POST', '/sapi/v1/managed-subaccount/withdraw', True]  # 投资人账户为托管子账户提币资产 (适用投资人母账户)
+    get_managed_subaccount_accountSnapshot = ['https://api.binance.com','GET', '/sapi/v1/managed-subaccount/accountSnapshot', True]  # 查询托管子账户资产快照 (适用投资人母账户)
 
 
 class SubAccount(Client):
