@@ -4,10 +4,10 @@ from pbinance.client import Client
 
 # 统一账户
 class _SPOTPortfolioMarginEndpoints():
-    portfolio_account = ['https://api.binance.com/','GET', '/sapi/v1/portfolio/account', True]  # 查询统一账户信息 (USER_DATA)
-    portfolio_collateralRate = ['https://api.binance.com/','GET', '/sapi/v1/portfolio/collateralRate', False]  # 统一账户资产质押率 (MARKET_DATA)
-    portfolio_pmLoan = ['https://api.binance.com/','GET', '/sapi/v1/portfolio/pmLoan', False]  # 查询统一账户穿仓借贷金额 (USER_DATA)
-    portfolio_repay = ['https://api.binance.com/','POST', '/sapi/v1/portfolio/repay', False]  # 偿还统一账户穿仓负债
+    portfolio_account = ['https://api.binance.com','GET', '/sapi/v1/portfolio/account', True]  # 查询统一账户信息 (USER_DATA)
+    portfolio_collateralRate = ['https://api.binance.com','GET', '/sapi/v1/portfolio/collateralRate', False]  # 统一账户资产质押率 (MARKET_DATA)
+    portfolio_pmLoan = ['https://api.binance.com','GET', '/sapi/v1/portfolio/pmLoan', False]  # 查询统一账户穿仓借贷金额 (USER_DATA)
+    portfolio_repay = ['https://api.binance.com','POST', '/sapi/v1/portfolio/repay', False]  # 偿还统一账户穿仓负债
 
 
 class SPOTPortfolioMargin(Client):
