@@ -5,37 +5,37 @@ from typing import Union
 
 # 账户和交易
 class _UMAccountTradeEndpoints():
-    set_positionSide_dual = ['https://fapi.binance.com/','POST', '/fapi/v1/positionSide/dual', True]  # 更改持仓模式(TRADE)
-    get_positionSide_dual = ['https://fapi.binance.com/','GET', '/fapi/v1/positionSide/dual', True]  # 查询持仓模式(USER_DATA)
-    set_multiAssetsMargin = ['https://fapi.binance.com/','POST', '/fapi/v1/multiAssetsMargin', True]  # 更改联合保证金模式(TRADE)
-    get_multiAssetsMargin = ['https://fapi.binance.com/','GET', '/fapi/v1/multiAssetsMargin', True]  # 查询联合保证金模式(USER_DATA)
-    set_order = ['https://fapi.binance.com/','POST', '/fapi/v1/order', True]  # 下单 (TRADE)
-    set_order_test = ['https://fapi.binance.com/','POST', '/fapi/v1/order/test', True]  # 测试下单接口 (TRADE)
-    set_batchOrders = ['https://fapi.binance.com/','POST', '/fapi/v1/batchOrders', True]  # 批量下单 (TRADE)
-    get_order = ['https://fapi.binance.com/','GET', '/fapi/v1/order', True]  # 查询订单 (USER_DATA)
-    cancel_order = ['https://fapi.binance.com/','DELETE', '/fapi/v1/order', True]  # 撤销订单 (TRADE)
-    cancel_allOpenOrders = ['https://fapi.binance.com/','DELETE', '/fapi/v1/allOpenOrders', True]  # 撤销全部订单 (TRADE)
-    cancel_batchOrders = ['https://fapi.binance.com/','DELETE', '/fapi/v1/batchOrders', True]  # 批量撤销订单 (TRADE)
-    set_countdownCancelAll = ['https://fapi.binance.com/','POST', '/fapi/v1/countdownCancelAll', True]  # 倒计时撤销所有订单 (TRADE)
-    get_openOrder = ['https://fapi.binance.com/','GET', '/fapi/v1/openOrder', True]  # 查询当前挂单 (USER_DATA)
-    get_openOrders = ['https://fapi.binance.com/','GET', '/fapi/v1/openOrders', True]  # 查看当前全部挂单 (USER_DATA)
-    get_allOrders = ['https://fapi.binance.com/','GET', '/fapi/v1/allOrders', True]  # 查询所有订单(包括历史订单) (USER_DATA)
-    get_balance = ['https://fapi.binance.com/','GET', '/fapi/v2/balance', True]  # 账户余额V2 (USER_DATA)
-    get_account = ['https://fapi.binance.com/','GET', '/fapi/v2/account', True]  # 账户信息V2 (USER_DATA)
-    set_leverage = ['https://fapi.binance.com/','POST', '/fapi/v1/leverage', True]  # 调整开仓杠杆 (TRADE)
-    set_marginType = ['https://fapi.binance.com/','POST', '/fapi/v1/marginType', True]  # 变换逐全仓模式 (TRADE)
-    set_positionMargin = ['https://fapi.binance.com/','POST', '/fapi/v1/positionMargin', True]  # 调整逐仓保证金 (TRADE)
-    get_positionMargin_history = ['https://fapi.binance.com/','GET', '/fapi/v1/positionMargin/history', True]  # 逐仓保证金变动历史 (TRADE)
-    get_positionRisk = ['https://fapi.binance.com/','GET', '/fapi/v2/positionRisk', True]  # 用户持仓风险V2 (USER_DATA)
-    get_userTrades = ['https://fapi.binance.com/','GET', '/fapi/v1/userTrades', True]  # 账户成交历史 (USER_DATA)
-    get_income = ['https://fapi.binance.com/','GET', '/fapi/v1/income', True]  # 获取账户损益资金流水 (USER_DATA)
-    get_leverageBracket = ['https://fapi.binance.com/','GET', '/fapi/v1/leverageBracket', False]  # 杠杆分层标准 (USER_DATA)
-    get_adlQuantile = ['https://fapi.binance.com/','GET', '/fapi/v1/adlQuantile', False]  # 持仓ADL队列估算 (USER_DATA)
-    get_forceOrders = ['https://fapi.binance.com/','GET', '/fapi/v1/forceOrders', False]  # 用户强平单历史 (USER_DATA)
-    get_apiTradingStatus = ['https://fapi.binance.com/','GET', '/fapi/v1/apiTradingStatus', False]  # 合约交易量化规则指标 (USER_DATA)
-    get_commissionRate = ['https://fapi.binance.com/','GET', '/fapi/v1/commissionRate', True]  # 用户手续费率 (USER_DATA)
-    get_income_asyn = ['https://fapi.binance.com/','GET', '/fapi/v1/income/asyn', True]  # 获取合约资金流水下载Id (USER_DATA)
-    get_income_asyn_id = ['https://fapi.binance.com/','GET', '/fapi/v1/income/asyn/id', True]  # 通过下载Id获取合约资金流水下载链接 (USER_DATA)
+    set_positionSide_dual = ['https://fapi.binance.com','POST', '/fapi/v1/positionSide/dual', True]  # 更改持仓模式(TRADE)
+    get_positionSide_dual = ['https://fapi.binance.com','GET', '/fapi/v1/positionSide/dual', True]  # 查询持仓模式(USER_DATA)
+    set_multiAssetsMargin = ['https://fapi.binance.com','POST', '/fapi/v1/multiAssetsMargin', True]  # 更改联合保证金模式(TRADE)
+    get_multiAssetsMargin = ['https://fapi.binance.com','GET', '/fapi/v1/multiAssetsMargin', True]  # 查询联合保证金模式(USER_DATA)
+    set_order = ['https://fapi.binance.com','POST', '/fapi/v1/order', True]  # 下单 (TRADE)
+    set_order_test = ['https://fapi.binance.com','POST', '/fapi/v1/order/test', True]  # 测试下单接口 (TRADE)
+    set_batchOrders = ['https://fapi.binance.com','POST', '/fapi/v1/batchOrders', True]  # 批量下单 (TRADE)
+    get_order = ['https://fapi.binance.com','GET', '/fapi/v1/order', True]  # 查询订单 (USER_DATA)
+    cancel_order = ['https://fapi.binance.com','DELETE', '/fapi/v1/order', True]  # 撤销订单 (TRADE)
+    cancel_allOpenOrders = ['https://fapi.binance.com','DELETE', '/fapi/v1/allOpenOrders', True]  # 撤销全部订单 (TRADE)
+    cancel_batchOrders = ['https://fapi.binance.com','DELETE', '/fapi/v1/batchOrders', True]  # 批量撤销订单 (TRADE)
+    set_countdownCancelAll = ['https://fapi.binance.com','POST', '/fapi/v1/countdownCancelAll', True]  # 倒计时撤销所有订单 (TRADE)
+    get_openOrder = ['https://fapi.binance.com','GET', '/fapi/v1/openOrder', True]  # 查询当前挂单 (USER_DATA)
+    get_openOrders = ['https://fapi.binance.com','GET', '/fapi/v1/openOrders', True]  # 查看当前全部挂单 (USER_DATA)
+    get_allOrders = ['https://fapi.binance.com','GET', '/fapi/v1/allOrders', True]  # 查询所有订单(包括历史订单) (USER_DATA)
+    get_balance = ['https://fapi.binance.com','GET', '/fapi/v2/balance', True]  # 账户余额V2 (USER_DATA)
+    get_account = ['https://fapi.binance.com','GET', '/fapi/v2/account', True]  # 账户信息V2 (USER_DATA)
+    set_leverage = ['https://fapi.binance.com','POST', '/fapi/v1/leverage', True]  # 调整开仓杠杆 (TRADE)
+    set_marginType = ['https://fapi.binance.com','POST', '/fapi/v1/marginType', True]  # 变换逐全仓模式 (TRADE)
+    set_positionMargin = ['https://fapi.binance.com','POST', '/fapi/v1/positionMargin', True]  # 调整逐仓保证金 (TRADE)
+    get_positionMargin_history = ['https://fapi.binance.com','GET', '/fapi/v1/positionMargin/history', True]  # 逐仓保证金变动历史 (TRADE)
+    get_positionRisk = ['https://fapi.binance.com','GET', '/fapi/v2/positionRisk', True]  # 用户持仓风险V2 (USER_DATA)
+    get_userTrades = ['https://fapi.binance.com','GET', '/fapi/v1/userTrades', True]  # 账户成交历史 (USER_DATA)
+    get_income = ['https://fapi.binance.com','GET', '/fapi/v1/income', True]  # 获取账户损益资金流水 (USER_DATA)
+    get_leverageBracket = ['https://fapi.binance.com','GET', '/fapi/v1/leverageBracket', False]  # 杠杆分层标准 (USER_DATA)
+    get_adlQuantile = ['https://fapi.binance.com','GET', '/fapi/v1/adlQuantile', False]  # 持仓ADL队列估算 (USER_DATA)
+    get_forceOrders = ['https://fapi.binance.com','GET', '/fapi/v1/forceOrders', False]  # 用户强平单历史 (USER_DATA)
+    get_apiTradingStatus = ['https://fapi.binance.com','GET', '/fapi/v1/apiTradingStatus', False]  # 合约交易量化规则指标 (USER_DATA)
+    get_commissionRate = ['https://fapi.binance.com','GET', '/fapi/v1/commissionRate', True]  # 用户手续费率 (USER_DATA)
+    get_income_asyn = ['https://fapi.binance.com','GET', '/fapi/v1/income/asyn', True]  # 获取合约资金流水下载Id (USER_DATA)
+    get_income_asyn_id = ['https://fapi.binance.com','GET', '/fapi/v1/income/asyn/id', True]  # 通过下载Id获取合约资金流水下载链接 (USER_DATA)
 
 
 class UMAccountTrade(Client):
